import {
  RestControllerClient,
  ConnectionRecordDto,
  CreateCredentialDefinitionRequestDto,
  CreateInvitationResponseDto,
  CreateSchemaRequestDto,
  CreddefRecordDto,
  IssueCredentialRequestDto,
  IdReqDto,
  SchemaRecordDto,
  CredentialRecordDto,
  CredentialFilterDto,
  MakeBasicMessageRequestDto,
  MessageFilterDto,
  MessageRecordDto,
  ProofRecordDto,
  ProofFilterDto,
  IssueProofRequestDto,
  ProofReqDto,
  ProofIssueResponseDto,
  CredentialIssueResponseDto
} from "./agent-client";
export interface Config {
  websocketUrl: string;
  gatewayUrl: string;
  getToken: () => Promise<string>;
}

let config: Config | null = null;

export const setConfig = (cfg: Config) => config = cfg;

interface GatewayMessageType {
  id: string;
  specversion: string;
  datacontenttype: string;
  subject: string;
  source: string;
  type: string;
  data: any;
}

// type RestControllerClientType = InstanceType<typeof RestControllerClient>;
// type OmittedRestControllerClientType = Omit<RestControllerClientType, 'http' | 'baseUrl'>;

type BasicMessageReceivedCallback = (event: MessageRecordDto) => void;

class ApiClient /* implements OmittedRestControllerClientType */ {
  private _ws!: WebSocket;
  private _wsMessages: GatewayMessageType[] = [];

  private _rest!: RestControllerClient;

  private _messageCallbacks: { id: string, cb: BasicMessageReceivedCallback }[] = [];
  public subscribeToBasicMessages = (cb: (event: MessageRecordDto) => void) => {
    const id = Math.random().toString();
    this._messageCallbacks.push({ id: id, cb });

    return () => {
      const index = this._messageCallbacks.findIndex(p => p.id === id);
      if (index >= 0) {
        this._messageCallbacks.splice(index, 1);
      }
    };
  }

  /* rest api methods */
  public createInvitation = (): Promise<CreateInvitationResponseDto> =>
    this._rest.createInvitation()

  public acceptInvitation = (body: CreateInvitationResponseDto): Promise<ConnectionRecordDto> =>
    this._rest.acceptInvitation(body);
  public connections = (): Promise<ConnectionRecordDto[]> =>
    this._rest.connections();
  public getConnectionById = (id: string): Promise<ConnectionRecordDto> =>
    this._rest.getConnectionById(id);
  public deleteConnectionById = (id: string): Promise<void> =>
    this._rest.deleteConnectionById(id);

  public createSchema = (body: CreateSchemaRequestDto): Promise<SchemaRecordDto> =>
    this._rest.createSchema(body);

  public listSchema = (): Promise<SchemaRecordDto[]> =>
    this._rest.listSchema();

  public getSchemaById = (body: IdReqDto): Promise<SchemaRecordDto> =>
    this._rest.getSchemaById(body);

  public credentialDefinitions = (): Promise<CreddefRecordDto[]> =>
    this._rest.credentialDefinitions();

  public getCredentialDefinitionsById = (body: IdReqDto): Promise<CreddefRecordDto> =>
    this._rest.getCredentialDefinitionsById(body);

  public createCredentialDefinition = (body: CreateCredentialDefinitionRequestDto): Promise<CreddefRecordDto> =>
    this._rest.createCredentialDefinition(body);

  public issueCredential = (body: IssueCredentialRequestDto): Promise<CredentialIssueResponseDto> =>
    this._rest.issueCredential(body);

  public credentials = (): Promise<CredentialRecordDto[]> =>
    this._rest.credentials();

  public credentialsQuery = (body: CredentialFilterDto): Promise<CredentialRecordDto[]> =>
    this._rest.credentialsQuery(body);

  public getCredentialById = (id: string): Promise<CredentialRecordDto> =>
    this._rest.getCredentialById(id);

  public deleteCredentialById = (id: string): Promise<void> =>
    this._rest.deleteCredentialById(id);

  public getCredentialOffers = (): Promise<CredentialRecordDto[]> =>
    this._rest.getCredentialOffers();

  public acceptCredential = (credential_record_id: string): Promise<CredentialRecordDto> =>
    this._rest.acceptCredential(credential_record_id);

  public declineCredential = (credential_record_id: string): Promise<CredentialRecordDto> =>
    this._rest.declineCredential(credential_record_id);

  public sendMessage = (body: MakeBasicMessageRequestDto): Promise<MessageRecordDto> =>
    this._rest.sendMessage(body);

  public queryMessages = (body: MessageFilterDto): Promise<MessageRecordDto[]> =>
    this._rest.queryMessages(body);

  public deleteMessage = (id: string): Promise<void> =>
    this._rest.deleteMessage(id);


  public proofs = (): Promise<ProofRecordDto[]> =>
    this._rest.proofs();

  public proofsQuery = (body: ProofFilterDto): Promise<ProofRecordDto[]> =>
    this._rest.proofsQuery(body);

  public getProofById = (proof_record_id: string): Promise<ProofRecordDto> =>
    this._rest.getProofById(proof_record_id);

  public deleteProofById = (proof_record_id: string): Promise<void> =>
    this._rest.deleteProofById(proof_record_id);

  public issueProof = (body: IssueProofRequestDto): Promise<ProofIssueResponseDto> =>
    this._rest.issueProof(body);

  public acceptProof = (body: ProofReqDto): Promise<ProofRecordDto> =>
    this._rest.acceptProof(body);

  public declineProofRequest = (proof_record_id: string): Promise<ProofRecordDto> =>
    this._rest.declineProofRequest(proof_record_id);

  public initialize() {
    console.log('init');
    const _config = config as Config;

    this._rest = new RestControllerClient(_config.gatewayUrl, { fetch: this._fetch.bind(this) });
    this._rest.jsonParseReviver = this.jsonParseReviver;

    // this._listen();
  }

  public async getToken(): Promise<string> {
    if (!config) {
      throw new Error("ApiClient: Please call setConfig before calling api")
    }

    return config.getToken();
  }

  // private _waitForResponse = async (gwPromise: Promise<GatewayAcceptedResponseDto>): Promise<any> => {
  //   const { id } = await gwPromise;
  //   return new Promise((resolve, reject) => {
  //     const timeout = setTimeout(() => {
  //       this._ws.removeEventListener('message', messageHandler); // Unsubscribe from events after the timeout
  //       reject(new Error('No response received in 5 minutes.');
  //     }, 5 * 60 * 1000); // 5 minutes in milliseconds
  //
  //     const messageHandler = (event: MessageEvent) => {
  //       const message = JSON.parse(event.data, this.jsonParseReviver) as GatewayMessageType;
  //       if (message.id === id) {
  //         clearTimeout(timeout); // Clear the timeout if the correct message is received
  //         this._ws.removeEventListener('message', messageHandler); // Unsubscribe from events after receiving the message
  //         resolve(message.data);
  //       }
  //     };
  //
  //     const existingMessage = this._wsMessages.find(m => m.id === id);
  //     if (existingMessage) {
  //       clearTimeout(timeout); // Clear the timeout if the correct message is received
  //       resolve(existingMessage.data);
  //       return;
  //     }
  //     this._ws.addEventListener('message', messageHandler);
  //   });
  // }

  private async _fetch(url: RequestInfo, init?: RequestInit): Promise<any> {
    if (!config) {
      throw new Error("ApiClient: Please call setConfig before calling api")
    }

    init = Object.assign({}, init, {
      headers: {
        ...(init?.headers || {}),
        Authorization: `Bearer ${await config.getToken()}`
      }
    });

    return fetch(url, init);
  }

  public jsonParseReviver = (key: string, value: any): any => {
    if (typeof value === 'string') {
      const a = /^(\d{4})-(\d{2})-(\d{2})T(\d{2}):(\d{2}):(\d{2}(?:\.\d*)?)Z?$/.exec(value);
      if (a) {
        return new Date(value);
      }
    }
    return value;
  }

  // private async _listen() {
  //   console.log("Opening connection to " + config!.websocketUrl);
  //   const ws = new WebSocket(config!.websocketUrl);
  //   this._ws = ws;
  //   // Connection opened
  //   ws.addEventListener('open', (event) => {
  //     console.log('Connected to the WebSocket');
  //   });
  //
  //   // Listen for messages
  //   ws.addEventListener('message', (event) => {
  //     console.log('Message from server: ', event.data);
  //     const data = JSON.parse(event.data, this.jsonParseReviver);
  //     this._checkIncomingBasicMessage(data);
  //     this._wsMessages.push(data);
  //   });
  //
  //   // Connection closed
  //   ws.addEventListener('close', (event) => {
  //     if (event.wasClean) {
  //       console.log(`Closed cleanly, code=${event.code}, reason=${event.reason}`);
  //     } else {
  //       console.log('Connection died');
  //     }
  //   });
  //
  //   // Connection errors
  //   ws.addEventListener('error', (error) => {
  //     console.error(`WebSocket Error: ${error}`);
  //   });
  // }

  // private _checkIncomingBasicMessage = (event: GatewayMessageType) => {
  //   if (event.source === "agent-basic-message-afj") {
  //     const data = event.data as MessageRecordDto;
  //
  //     this._messageCallbacks.forEach(subscription => subscription.cb(data));
  //   }
  // }
}

export default new ApiClient();
