import React, { useEffect, useState } from "react";
import { Button, Spin } from "antd";
import { toast, ToastContainer } from "react-toastify";
import PageRoutes from "@dashboard/routes";
import modalStore from "@dashboard/store/modalStore";
import { observer } from "mobx-react";
import api from "@dashboard/api";
import { useNavigate } from "react-router-dom";
import config from "@dashboard/routes/config";
import s from "./styles.module.scss";

const App = observer(() => {
  const navigate = useNavigate();
  const [isAppLoading, setIsAppLoading] = useState(true);

  useEffect(() => {
    (async () => {
      api.subscribeToBasicMessages((message) => {
        toast.info(
          <div>
            You received a new message from{" "}
            {message.from || message.connectionId}.
            <div>
              <Button
                type="primary"
                onClick={() => {
                  navigate(
                    config.connection_view.getLink(message.connectionId),
                  );
                }}
              >
                View message
              </Button>
            </div>
          </div>,
        );
      });
      setTimeout(() => {
        setIsAppLoading(false);
      }, 2000)
    })();
  }, []);

  let content;
  if (isAppLoading) {
    content = (
      <div className={s.loader}>
        <img className={s.loaderLogo} src="https://www.vereign.com/vereign-logo.svg" />
      </div>
    );
  } else {
    content = (
      <PageRoutes />
    );
  }
  return (
    <div className={s.root}>
      {content}
      <ToastContainer />
      {modalStore.modals.map((p) => (
        <React.Fragment key={p.id}>{p.modal}</React.Fragment>
      ))}
    </div>
  );
});

export default App;
