import {makeAutoObservable, runInAction} from "mobx";
import api from "@dashboard/api";
import {toast} from "react-toastify";
import {MessageRecordDto} from "@dashboard/api/agent-client";


class BasicMessageListStore {
  public loading = false;
  public sendingMessage = false;
  public items: MessageRecordDto[] = [];
  constructor() {
    makeAutoObservable(this);
  }

  public async loadAll(connectionId: string | null) {
    runInAction(() => this.loading = true);
    try {
      const items = await api.queryMessages({
        connectionId: connectionId || undefined,
      });
      runInAction(() => {
        this.items = items;
        this.loading = false;
      });
    } catch (e: any) {
      toast(e.message);
      console.error(e);
      runInAction(() => this.loading = false);
    }
  }

  public sendMessage = async (connectionId: string, content: string) => {
    runInAction(() => this.sendingMessage = true);
    try {
      const message = await api.sendMessage({
        connectionId: connectionId,
        content: content
      });
      runInAction(() => {
        this.items.push(message);
        this.sendingMessage = false;
      });
      return true;
    } catch (e: any) {
      toast(e.message);
      console.error(e);
      runInAction(() => this.sendingMessage = false);
    }
    return false;
  }
}

export type { BasicMessageListStore };

export default BasicMessageListStore;
