import React from "react";
import { observer } from "mobx-react";
import classNames from "classnames";
import format from "date-fns/format";
import {ConnectionRecordDto} from "@dashboard/api/agent-client";
import RecordItem from "@dashboard/components/RecordItem";
import s from './styles.module.scss';
import { Tag } from "antd";

interface ConnectionItemProps {
  item: ConnectionRecordDto;
  onClick?: () => void;
}

const ConnectionItem = observer(({ item, onClick }: ConnectionItemProps) => {
  return (
    <RecordItem onClick={onClick} rawData={item}>
      {item.connectionName && (
        <div className={s.prop}>
          Their label: <b>{item.connectionName}</b>
        </div>
      )}
      <div className={s.prop}>
        Status: <Tag>{item.state}</Tag>
      </div>
      <div className={s.prop}>
        ConnectionId: {item.id}
      </div>

      <div className={s.createdAt}>
        {item.createdAt && format(item.createdAt, 'dd.MM.yyyy HH:mm:ss')}
      </div>
    </RecordItem>
  );
});

export default ConnectionItem;

