import React from "react";
import { observer } from "mobx-react";
import {Button, Space, Tag} from "antd";
import {CredentialRecordDto, CredentialRecordDtoState} from "@dashboard/api/agent-client";
import s from './styles.module.scss';
import RecordItem from "../RecordItem";
import format from "date-fns/format";

interface CredentialItemProps {
  item: CredentialRecordDto;
  onOpen?: () => void;
  onRemove?: () => void;
  onAccept: () => void;
  onDecline: () => void;
  statusChanging: boolean;
}

const CredentialItem = observer(({
  item,
  onOpen,
  onRemove,
  onAccept,
  onDecline,
  statusChanging
}: CredentialItemProps) => {
  return (
    <RecordItem rawData={item}>
      <div className={s.prop}>
        Status: <Tag>{item.state}</Tag>
      </div>
      <div className={s.prop}>
        Attbiutes: {item.attributes?.map(p => (
          <Tag color="green" key={p.name}>{p.name}: {p.value}</Tag>
      ))}
      </div>
      <div className={s.createdAt}>
        {item.createdAt && format(item.createdAt, 'dd.MM.yyyy HH:mm:ss')}
      </div>
      <Space direction="horizontal">
        {onOpen && <Button onClick={onOpen}>Go to credential</Button>}
        {item.state === CredentialRecordDtoState.OfferReceived && (
          <Button disabled={statusChanging} onClick={onAccept} type="primary">
            Accept
          </Button>
        )}
        {item.state === CredentialRecordDtoState.OfferReceived && (
          <Button disabled={statusChanging} onClick={onDecline} danger>
            Decline
          </Button>
        )}
        {onRemove && <Button disabled={statusChanging} danger onClick={onRemove}>Delete</Button>}
      </Space>
    </RecordItem>
  );
});

export default CredentialItem;

