import {makeAutoObservable, runInAction} from "mobx";
import api from "@dashboard/api";
import {toast} from "react-toastify";
import {CredentialRecordDto} from "@dashboard/api/agent-client";


class CredentialListStore {
  public loading = false;
  public items: CredentialRecordDto[] = [];

  public statusChangeId: string | null = null;
  constructor() {
    makeAutoObservable(this);
  }

  public async loadAll(connectionId: string | null) {
    runInAction(() => this.loading = true);
    try {
      const items = await api.credentialsQuery({
        connectionId: connectionId || undefined,
      });
      runInAction(() => {
        this.items = items;
        this.loading = false;
      });
    } catch (e: any) {
      toast(e.message);
      console.error(e);
      runInAction(() => this.loading = false);
    }
  }

  public async accept(credId: string) {
    runInAction(() => {
      this.statusChangeId = credId;
    });
    try {
      const credRecord = await api.acceptCredential(credId);
      runInAction(() => {
        const index = this.items.findIndex(p => p.id === credRecord.id);
        if (index >= 0) {
          this.items[index] = credRecord;
        }
        this.statusChangeId = null;
      });
    } catch (e: any) {
      toast(e.message);
      console.error(e);
      runInAction(() => this.loading = false);
    }
  }

  public async decline(credId: string) {
    runInAction(() => {
      this.statusChangeId = credId;
    });
    try {
      const credRecord = await api.declineCredential(credId);
      runInAction(() => {
        const index = this.items.findIndex(p => p.id === credRecord.id);
        if (index >= 0) {
          this.items[index] = credRecord;
        }
        this.statusChangeId = null;
      });
    } catch (e: any) {
      toast(e.message);
      console.error(e);
      runInAction(() => this.loading = false);
    }
  }

  public async remove(credId: string) {
    runInAction(() => {
      this.statusChangeId = credId;
    });
    try {
      await api.deleteCredentialById(credId);
      runInAction(() => {
        const index = this.items.findIndex(p => p.id === credId);
        if (index >= 0) {
          this.items.splice(index, 1);
        }
        this.statusChangeId = null;
      });
    } catch (e: any) {
      toast(e.message);
      console.error(e);
      runInAction(() => this.loading = false);
    }
  }
}

export type { CredentialListStore };

export default CredentialListStore;
