import React, {useEffect, useState} from "react";
import {observer} from "mobx-react";
import {Spin} from 'antd';
import CredentialItem from "@dashboard/components/CredentialItem";
import CredentialListStore from './CredentialListStore';
import NoRecordsMessage from "../NoRecordsMessage";

export interface CredentialListProps {
  connectionId: string | null;
}

const CredentialList: React.FC<CredentialListProps> = observer(({ connectionId }) => {
  const [store] = useState(() => new CredentialListStore());

  useEffect(() => {
    store.loadAll(connectionId)
  }, [])
  return (
    <div>
      {store.items.map(p => (
        <CredentialItem
          key={p.id}
          item={p}
          onAccept={() => store.accept(p.id)}
          onDecline={() => store.decline(p.id)}
          statusChanging={store.statusChangeId === p.id}
          onRemove={() => store.remove(p.id)}
        />
      ))}
      {!store.loading && !store.items.length && (
        <NoRecordsMessage />
      )}
      {store.loading && (
        <Spin />
      )}
    </div>
  );
});

export default CredentialList;
