import React, { useEffect, useState } from "react";
import { Modal as ModalAntd } from "antd";
import Body from './Body';
import Footer from './Footer';

export interface ModalEvent {
  close: () => void;
}

export interface FcProps<TData> {
  setTitle: (title: string) => void;
  setClassName: (name: string) => void;
  setWrapClassName: (name: string) => void;
  setWidth: (width: string | number) => void;
  onClose: () => void;
  data: TData
}

export interface ModalProps<TData> {
  Component: React.FC<FcProps<TData>>;
  onClose: () => void;
  data: TData;
}

function Modal<TData>({ Component, onClose, data }: ModalProps<TData>) {
  const [title, setTitle] = useState('Loading');
  const [className, setClassName] = useState<string | undefined>();
  const [width, setWidth] = useState<string | number | undefined>();
  const [wrapClassName, setWrapClassName] = useState<string | undefined>();
  const [open, setOpen] = useState(false);

  useEffect(() => setOpen(true), []);

  return (
    <ModalAntd
      title={title}
      open={open}
      footer={null}
      width={width}
      className={className}
      wrapClassName={wrapClassName}
      onCancel={onClose}
      maskClosable={false}
    >
      <Component
        setTitle={setTitle}
        onClose={onClose}
        setWidth={setWidth}
        setClassName={setClassName}
        setWrapClassName={setWrapClassName}
        data={data}
      />
    </ModalAntd>
  );
}

Modal.Body = Body;
Modal.Footer = Footer;

export default Modal;
