import React from "react";
import { observer } from "mobx-react";
import {Button, Space, Tag} from "antd";
import {ProofRecordDto} from "@dashboard/api/agent-client";
import s from './styles.module.scss';
import RecordItem from "../RecordItem";
import format from "date-fns/format";

interface ProofItemProps {
  item: ProofRecordDto;
  onOpen?: () => void;
  onRemove?: () => void;
  onAccept?: () => void;
  onDecline?: () => void;
  statusChanging?: boolean;
}

const ProofItem = observer(({
  item,
  onOpen,
  onRemove,
  onAccept,
  onDecline,
  statusChanging,
}: ProofItemProps) => {
  return (
    <RecordItem rawData={item}>
      <div className={s.prop}>
        Status: <Tag>{item.state}</Tag>
      </div>
      <div className={s.prop}>
        ProofId: {item.id}
      </div>

      <div className={s.createdAt}>
        {item.createdAt && format(item.createdAt, 'dd.MM.yyyy HH:mm:ss')}
      </div>

      <Space direction="horizontal">
        {onOpen && <Button onClick={onOpen}>Go to credential</Button>}
        {onAccept && item.state === 'request-received' && (
          <Button disabled={statusChanging} onClick={onAccept} type="primary">
            Accept
          </Button>
        )}
        {onDecline && item.state === 'request-received' && (
          <Button disabled={statusChanging} onClick={onDecline} danger>
            Decline
          </Button>
        )}
        {onRemove && <Button onClick={onRemove}>Remove</Button>}
      </Space>
    </RecordItem>
  );
});

export default ProofItem;

