import React, {useEffect, useState} from "react";
import {observer} from "mobx-react";
import {Spin} from 'antd';
import ProofListStore from './ProofListStore';
import NoRecordsMessage from "../NoRecordsMessage";
import ProofItem from "@dashboard/components/ProofItem";

export interface ProofListProps {
  connectionId: string | null;
}

const ProofList: React.FC<ProofListProps> = observer(({ connectionId }) => {
  const [store] = useState(() => new ProofListStore());

  useEffect(() => {
    store.loadAll(connectionId)
  }, [])
  return (
    <div>
      {store.items.map(p => (
        <ProofItem
          key={p.id}
          item={p}
          onAccept={() => store.accept(p.id)}
          onDecline={() => store.decline(p.id)}
          statusChanging={store.statusChangeId === p.id}
          onRemove={() => store.remove(p.id)}
        />
      ))}
      {!store.loading && !store.items.length && (
        <NoRecordsMessage />
      )}
      {store.loading && (
        <Spin />
      )}
    </div>
  );
});

export default ProofList;
