import React, { useEffect, useState } from "react";
import { observer } from "mobx-react";
import { Form, Input, Button } from 'antd';
import api from "@dashboard/api";
import {toast} from "react-toastify";
import Modal, {FcProps} from "@dashboard/components/Modal";
import {ProofRecordDto} from "@dashboard/api/agent-client";
import s from "./styles.module.scss";

export interface AcceptConnectionlessProofRequestDialogProps {
  onProofReceived: (proofRecord: ProofRecordDto) => void;
}

const AcceptConnectionlessProofRequestDialog = observer(({
  setTitle,
  onClose,
  data
}: FcProps<AcceptConnectionlessProofRequestDialogProps>) => {
  useEffect(() => {
    setTitle('Accept proof request by URL');
  }, []);

  const [loading, setLoading] = useState(false);

  const onFinish = async ({ proofUrl }: any) => {
    try {
      setLoading(true);
      const proofRecord = await api.acceptProof({
        proofUrl,
        proofId: ""
      });
      toast(`Proof request accepted`);
      if (proofRecord) {
        data.onProofReceived(proofRecord);
        onClose();
      }
    } catch (e: any) {
      console.error(e);
      toast(e.message);
    }
    setLoading(false);
  };

  return (
    <Modal.Body>
      <div className={s.body}>
        <Form
          layout="vertical"
          initialValues={{
            proofUrl: ''
          }}
          onFinish={onFinish}
          autoComplete="off"
        >
          <Form.Item
            label="proof url"
            name="proofUrl"
            rules={[{ required: true, message: 'Please enter proof url!' }]}
          >
            <Input.TextArea rows={12} />
          </Form.Item>

          <div className={s.footerActions}>
            <Button type="primary" htmlType="submit" disabled={loading}>
              Accept
            </Button>
            <Button
              className={s.cancelButton}
              onClick={onClose}
              disabled={loading}
            >
              Close
            </Button>
          </div>
        </Form>
      </div>
    </Modal.Body>
  );
});

export default AcceptConnectionlessProofRequestDialog;
