import React, {useEffect, useState} from "react";
import Modal, {FcProps, ModalEvent} from "@dashboard/components/Modal";
import { Button } from "antd";

export interface ConfirmDialogProps {
  title: string;
  description: string | React.ReactNode;
  onOk: (e: ModalEvent) => Promise<void>;
  onCancel?: (e: ModalEvent) => Promise<void>;
}

const ConfirmDialog = ({
  setTitle,
  onClose,
  data
}: FcProps<ConfirmDialogProps>) => {
  useEffect(() => setTitle(data.title), [data.title]);
  const [loading, setLoading] = useState(false);

  return (
    <Modal.Body>
      <div>{data.description}</div>
      <Modal.Footer>
        <Button
          type="primary"
          disabled={loading}
          onClick={async () => {
            setLoading(true);
            try {
              await data.onOk({ close: onClose });
            } catch (e: any) {
              console.error(e);
            }
            setLoading(false);
          }}
        >
          Confirm
        </Button>
        <Button onClick={() => {
          onClose();
          data.onCancel && data.onCancel({
            close: onClose
          });
        }}>
          Cancel
        </Button>
      </Modal.Footer>
    </Modal.Body>
  );
};

export default ConfirmDialog;
