import {makeAutoObservable, runInAction} from "mobx";
import api from "@dashboard/api";
import {toast} from "react-toastify";
import {CreddefRecordDto, SchemaRecordDto} from "@dashboard/api/agent-client";


class IssueCredentialDialogStore {
  public initLoading = false;
  public connectionId!: string;
  public credDefList: CreddefRecordDto[] = [];
  public selectedCredDefId: string | null = null;
  public schemaLoading = false;
  public schema: SchemaRecordDto | null = null;

  public issuingLoading = false;


  constructor() {
    makeAutoObservable(this);
  }

  public async init(connectionId: string) {
    runInAction(() => {
      this.initLoading = true;
      this.connectionId = connectionId;
    });
    try {
      const credDefList = await api.credentialDefinitions();
      runInAction(() => {
        this.credDefList = credDefList;
        this.initLoading = false;
      });
    } catch (e: any) {
      console.error(e);
      toast.error(e.message);
      runInAction(() => this.initLoading = false);
    }
  }

  public selectCredDef = async (credentialDefId: string) => {
    runInAction(() => {
      this.selectedCredDefId = credentialDefId;
      this.schema = null;
      this.schemaLoading = true;
    })
    const credDef = this.credDefList.find(p => p.id === credentialDefId);

    try {
      const schema = await api.getSchemaById({
        id: credDef!.schemaId!
      });
      runInAction(() => {
        this.schema = schema;
        this.schemaLoading = false;
      });
    } catch (e: any) {
      console.error(e);
      toast.error(e.message);
      runInAction(() => this.schemaLoading = false);
    }
  }

  public issueCredential = async (attributes: { name: string; value: string }[]) => {
    runInAction(() => this.issuingLoading = true);
    try {
      const cred = await api.issueCredential({
        connectionId: this.connectionId,
        credentialDefinitionId: this.selectedCredDefId!,
        attributes: attributes
      });
      toast("Credential offer sent");
      runInAction(() => {
        this.issuingLoading = false;
      });
      return cred
    } catch (err: any) {
      toast(err.message);
      console.error(err)
      runInAction(() => {
        this.issuingLoading = false;
      });
    }
    return null
  }

}

export type { IssueCredentialDialogStore };

export default IssueCredentialDialogStore;
