import React, { useEffect, useState } from "react";
import { observer } from "mobx-react";
import {Form, Input, Button, Select} from 'antd';
import api from "@dashboard/api";
import {toast} from "react-toastify";
import Modal, {FcProps} from "@dashboard/components/Modal";
import s from "./styles.module.scss";
import {CreateSchemaRequestDto, SchemaRecordDto} from "@dashboard/api/agent-client";


export interface NewSchemaDialogProps {
  onSchemaCreated: (schema: SchemaRecordDto) => void;
}

const NewSchemaDialog = observer(({
  setTitle,
  onClose,
  data
}: FcProps<NewSchemaDialogProps>) => {
  useEffect(() => {
    setTitle('Add new schema');
  }, []);
  const [loading, setLoading] = useState(false);

  const onFinish = async (values: CreateSchemaRequestDto) => {
    try {
      setLoading(true);
      const schema = await api.createSchema(values);
      toast(`New schema ${schema.id} created`);
      data.onSchemaCreated(schema);
      onClose();
    } catch (e: any) {
      console.error(e);
      toast(e.message);
    }
    setLoading(false);
  };

  return (
    <Modal.Body>
      <div className={s.body}>
        <Form
          layout="vertical"
          labelCol={{ span: 8 }}
          wrapperCol={{ span: 16 }}
          style={{ maxWidth: 600 }}
          initialValues={{
            name: '',
            version: '',
            attributes: []
          }}
          onFinish={onFinish}
          autoComplete="off"
        >
          <Form.Item
            label="Name"
            name="name"
            rules={[{ required: true, message: 'Please enter name!' }]}
          >
            <Input />
          </Form.Item>
          <Form.Item
            label="Version"
            name="version"
            rules={[{ required: true, message: 'Please enter version!' }]}
          >
            <Input />
          </Form.Item>
          <Form.Item
            label="Attributes"
            name="attributes"
            rules={[{ required: true, message: 'Please enter attributes!' }]}
          >
            <Select
              mode="tags"
              style={{ width: '100%' }}
            />
          </Form.Item>

          <div className={s.footerActions}>
            <Button type="primary" htmlType="submit" disabled={loading}>
              Create
            </Button>
            <Button
              className={s.cancelButton}
              onClick={onClose}
              disabled={loading}
            >
              Close
            </Button>
          </div>
        </Form>

      </div>
    </Modal.Body>
  );
});

export default NewSchemaDialog;
