import React, { useEffect, useState } from "react";
import { observer } from "mobx-react";
import {Button, Spin, Select, Space} from 'antd';
import Modal, {FcProps} from "@dashboard/components/Modal";
import {ProofIssueResponseDto} from "@dashboard/api/agent-client";
import RequestProofDialogStore from "./RequestProofDialogStore";
import s from "./styles.module.scss";

export interface RequestProofDialogProps {
  connectionId?: string;
  onProofRequestIssued: (cred: ProofIssueResponseDto) => void;
}

const RequestProofDialog = observer(({
  setTitle,
  onClose,
  data
}: FcProps<RequestProofDialogProps>) => {
  const [store] = useState(() => new RequestProofDialogStore());
  useEffect(() => {
    if (data.connectionId) {
      setTitle('Request proof from ' + data.connectionId);
    } else {
      setTitle('Create connectionless proof request');
    }

    store.init(data.connectionId);
  }, []);

  return (
    <Modal.Body>
      {store.initLoading && (
        <Spin>
          Loading credential definitions...
        </Spin>
      )}

      <div>
        {store.rows.map((row, rowIndex) => (
          <Space direction="horizontal" className={s.row} key={rowIndex}>
            <Select
              placeholder="Select credential"
              // style={{ width: 300 }}
              value={row.credentialDefinitionId}
              showSearch
              onChange={val => store.selectCredDef(rowIndex, val)}
              options={store.credDefList.map(p => ({
                value: p.id,
                label: p.tag || p.id
              }))}
            />
            {row.schemaLoading && (
              <Spin />
            )}
            {row.schema && (
              <Select
                placeholder="Select attribute"
                // style={{ width: 300 }}
                value={row.attributeName}
                showSearch
                onChange={val => store.selectAttributeName(rowIndex, val)}
                options={row.schema.attributes.map(p => ({
                  value: p,
                  label: p
                }))}
              />
            )}
            <Button disabled={row.schemaLoading} onClick={() => store.removeRow(rowIndex)}>Remove</Button>
          </Space>
        ))}
        <Space direction="vertical" className={s.actions}>
          <Button onClick={() => store.addRow()}>Add row</Button>
          <Button
            type="primary"
            disabled={store.issuingLoading}
            onClick={async () => {
              const pr = await store.issueProofRequest();
              if (pr) {
                data.onProofRequestIssued(pr);
                onClose();
              }
            }}
          >
            Request proof
          </Button>
        </Space>
      </div>

    </Modal.Body>
  );
});

export default RequestProofDialog;
