import React, { useEffect } from "react";
import { observer } from "mobx-react";
import Modal, {FcProps} from "@dashboard/components/Modal";
import {ProofRecordDto} from "@dashboard/api/agent-client";
import ProofItem from "@dashboard/components/ProofItem";
import s from "./styles.module.scss";
import {QRCode} from "antd";

export interface ViewConnectionlessProofRequestProps {
  proofUrl: string;
  proofRecord: ProofRecordDto;
}

const ViewConnectionlessProofRequest = observer(({
  setTitle,
  setWidth,
  setClassName,
  onClose,
  data
}: FcProps<ViewConnectionlessProofRequestProps>) => {
  useEffect(() => {
    setClassName(s.modal);
    setWidth('80vw');
    setTitle('Connectionless proof request');
  }, []);

  return (
    <Modal.Body className={s.body}>
      <div className={s.info}>
        <div>
          <div className={s.qrCodeHint}>
            Scan this QR code with mobile wallet
          </div>
          <div className={s.qrWrapper}>
            <QRCode
              value={data.proofUrl}
              size={500}
            />
          </div>
          <div>
            <div className={s.urlTitle}>
              Proof request URL:
            </div>
            <div className={s.url}>
              <b>
                {data.proofUrl}
              </b>
            </div>
            <div className={s.urlHint}>
              Copy this URL and send it to the person you want to request proof from
            </div>
            <br />
            {data.proofRecord.oob && (
              <div>
                Details:
                <ProofItem
                  item={data.proofRecord}
                />
              </div>
            )}
          </div>
        </div>
      </div>
    </Modal.Body>
  );
});

export default ViewConnectionlessProofRequest;
