import React, {useEffect, useState} from "react";
import { observer } from "mobx-react";
import {QRCode, Spin} from 'antd';
import ConnectionCreatePageStore from './ConnectionCreatePageStore';
import s from './styles.module.scss';
import PageWithSidebar from "@dashboard/components/PageWithSidebar";
import PageTitle from "@dashboard/components/PageTitle";

const ConnectionCreatePage = observer(() => {
  const [store] = useState(() => new ConnectionCreatePageStore());

  useEffect(() => {
    store.createConnection();
  }, [])
  return (
    <PageWithSidebar>
      <PageTitle>New Connection invitation</PageTitle>
      <div>
        {store.loading && (
          <Spin />
        )}
        {!store.loading && (
          <>
            <div className={s.info}>
              <div>
                <div>
                  <div className={s.urlTitle}>
                    Invitation URL:
                  </div>
                  <div className={s.url}>
                    <b>
                      {store.invitationUrl}
                    </b>
                  </div>
                  <div className={s.urlHint}>
                    Copy this URL and send it to the person you want to connect with
                  </div>


                  <div className={s.qrCodeHint}>
                    Or scan this QR code with your mobile wallet
                  </div>
                  <div style={{ background: "white", padding: "16px" }}>
                    <QRCode
                      status={!store.invitationUrl ? "loading" : "active"}
                      value={store.invitationUrl || "loading"}
                      size={400}
                    />
                  </div>
                  <br />
                  {store.oob && (
                    <div>
                      Details:
                      <pre>
                        {store.oob}
                      </pre>
                    </div>
                  )}
                </div>
              </div>
            </div>
          </>
        )}
      </div>
    </PageWithSidebar>
  );
});

export default ConnectionCreatePage;
