import {makeAutoObservable, runInAction} from "mobx";
import {toast} from "react-toastify";
import api from "@dashboard/api";
import { ConnectionRecordDto } from "@dashboard/api/agent-client";

class ConnectionViewPageStore {
  public loading = false;
  public connection: ConnectionRecordDto | null = null;
  constructor() {
    makeAutoObservable(this);
  }

  public async load(id: string) {
    runInAction(() => this.loading = true);
    try {
      const record = await api.getConnectionById(id);
      runInAction(() => {
        this.connection = record;
        this.loading = false;
      });
    } catch (e: any) {
      console.error(e);
      toast.error(e.message);
      runInAction(() => this.loading = false);
    }
  }
}

export type { ConnectionViewPageStore };

export default ConnectionViewPageStore;
