import React, {useEffect, useState} from "react";
import { observer } from "mobx-react";
import {useParams} from "react-router-dom";
import ConnectionViewPageStore from './ConnectionViewPageStore';
import ConnectionItem from "@dashboard/components/ConnectionItem";
import {Button, Space, Spin} from "antd";
import JsonDetails from "@dashboard/components/JsonDetails";
import CredentialList from "@dashboard/components/CredentialList";
import ProofList from "@dashboard/components/ProofList";
import modalStore from "@dashboard/store/modalStore";
import BasicMessageList from "@dashboard/components/BasicMessageList";
import PageWithSidebar from "@dashboard/components/PageWithSidebar";
import PageTitle from "@dashboard/components/PageTitle";


const ConnectionViewPage = observer(() => {
  const { id } = useParams() as any;
  const [store] = useState(() => new ConnectionViewPageStore());

  useEffect(() => {
    store.load(id);
  }, [id])
  return (
    <PageWithSidebar>
      <h2>
        Actions
      </h2>
      <Space direction="horizontal">
        <Button
          onClick={() => {
            modalStore.openIssueCredentialDialog({
              connectionId: id,
              onCredentialIssued: (cred) => {
                setTimeout(() => {
                  window.location.reload();
                }, 3000);
              }
            })
          }}
        >
          Issue credential
        </Button>
        <Button
          onClick={() => {
            modalStore.openRequestProofDialog({
              connectionId: id,
              onProofRequestIssued: (proofRequest) => {
                setTimeout(() => {
                  window.location.reload();
                }, 3000);
              }
            })
          }}
        >
          Request proof
        </Button>
      </Space>
      <PageTitle>
        Connection
      </PageTitle>
      {store.loading && (
        <Spin />
      )}
      {!store.loading && (
        <>
          {store.connection && (
            <div>
              <ConnectionItem item={store.connection} />
            </div>
          )}
        </>
      )}

      <h3>Credentials</h3>
      <CredentialList connectionId={id} />

      <h3>Proofs</h3>
      <ProofList connectionId={id} />

      <h3>Messages</h3>
      <BasicMessageList connectionId={id} />

      <JsonDetails object={store.connection} />
    </PageWithSidebar>
  );
});

export default ConnectionViewPage;
