import React, {useEffect, useState} from "react";
import { observer } from "mobx-react";
import {Button, Spin} from 'antd';
import CredentialDefinitionItem from "@dashboard/components/CredentialDefinitionItem";
import CredentialDefListPageStore from "./CredentialDefListPageStore";
import modalStore from "@dashboard/store/modalStore";
import NoRecordsMessage from "@dashboard/components/NoRecordsMessage";
import PageWithSidebar from "@dashboard/components/PageWithSidebar";
import PageTitle from "@dashboard/components/PageTitle";

const CredentialDefListPage = observer(() => {
  const [store] = useState(() => new CredentialDefListPageStore());
  const [newCredDef, setNewCredDef] = useState('');

  useEffect(() => {
    store.getAll();
  }, []);

  return (
    <PageWithSidebar>
      <h2>
        Actions
      </h2>
      <div>
        <Button onClick={() => {
          modalStore.openNewCredentialDefDialog({
            onCredDefCreated: (credDef) => {
              try {
                setNewCredDef(JSON.stringify(credDef, null, 2))
              } catch (e: any) { }
              store.getAll();
            }
          });
        }}>
          Create new credential definition
        </Button>
      </div>
      {newCredDef && (
        <div>
          New credential definition:
          <pre>
            {newCredDef}
          </pre>
        </div>
      )}
      <PageTitle>Credential definitions</PageTitle>
      <div>
        {store.list.map(p => (
          <CredentialDefinitionItem
            key={p.credentialDefinitionId}
            item={p}
          />
        ))}
        {!store.loading && store.list.length === 0 && (
          <NoRecordsMessage />
        )}
        {store.loading && (
          <Spin />
        )}
      </div>
    </PageWithSidebar>
  );
});

export default CredentialDefListPage;

