import React, { useEffect, useState } from "react";
import { observer } from "mobx-react";
import LoginPageStore from "./LoginPageStore";
import {Button, Form, Input, QRCode, Spin} from "antd";
import Page from "@dashboard/components/Page";
import VaultHeader from "@dashboard/components/VaultHeader";
import {Link} from "react-router-dom";
import config from "@dashboard/routes/config";
import s from './styles.module.scss';

const LoginPage = observer(() => {
  const [store] = useState(() => new LoginPageStore());
  useEffect(() => {
    store.initialize();
  }, []);

  return (
    <Page>
      <VaultHeader hideTry />

      <div className={s.topSpace} />
      <div className={s.info}>
        <div className={s.subTitle}>
          Secure Login with Your Credentials
        </div>
        <ul>
          <li>
            <b>Open the Mobile App:</b> Launch the mobile app you downloaded and set up during registration.
          </li>
          <li>
            <b>Scan the QR Code Below:</b> Using the app's scanner, capture the QR code displayed on this page. This proves that you have valid credentials issued by our system.
          </li>
          <li>
            <b>Confirm and Login:</b> After scanning, the app will ask for your confirmation. Once confirmed, you will be automatically logged into the system.
          </li>
        </ul>

        <div>
          Remember, by using this method, we ensure a secure and seamless login experience. Your credentials are verified without the need for traditional passwords, making it safer and more convenient for you.
        </div>
      </div>

      <div className={s.registerForm}>
        <div className={s.formTitle}>Scan this QR code</div>

        <div className={s.qrWrapper}>
          <QRCode
            status={(!store.shortProofUrl || store.loading) ? "loading" : "active"}
            value={store.shortProofUrl || "loading"}
            size={400}
            icon="/assets/Vereign_Logo_ICON_BLACK.png"
          />
        </div>
      </div>

      <div className={s.goToLogin}>
        <Link to={config.connection_list.getLink()}>
          Go to dashboard
        </Link>
      </div>
    </Page>
  );
});

export default LoginPage;
