import {makeAutoObservable, runInAction} from "mobx";
import api from "@dashboard/api";
import {
  ConnectionRecordDto,
  CreddefRecordDto,
  CredentialRecordDto,
  IssueCredentialAttributes,
  SchemaRecordDto
} from "@dashboard/api/agent-client";
import {toast} from "react-toastify";
import {v4} from "uuid";


class RegisterPageStore {
  public loading = false;
  public id = v4();
  public schemaId = 'did:indy:bcovrin:test:FcZ4aS728oRGVdNUKVaECP/anoncreds/v0/SCHEMA/Identity/1.0';
  public schema: SchemaRecordDto | null = null;
  public creddef: CreddefRecordDto | null = null;
  public shortCredentialUrl: string | null = null;
  public credentialUrl: string | null = null;
  public credentialRecord: CredentialRecordDto | null = null;

  constructor() {
    makeAutoObservable(this);
  }

  public async initializeQr(name: string) {
    runInAction(() => this.loading = true);
    try {
      const schema = await api.getSchemaById({ id: this.schemaId });
      const credDefs = await api.credentialDefinitions();
      let requiredCredDef = credDefs.find((credDef) => credDef.schemaId === this.schemaId);
      if (!requiredCredDef) {
        requiredCredDef = await api.createCredentialDefinition({ schemaId: this.schemaId, tag: 'Identity' });
      }

      const { shortCredentialUrl, credentialUrl, credentialRecord } = await api.issueCredential({
        credentialDefinitionId: requiredCredDef.id,
        attributes: [
          {
            name: 'internal-id',
            value: this.id,
          },
          {
            name: 'name',
            value: name,
          }
        ]
      })
      runInAction(() => {
        this.schema = schema;
        this.creddef = requiredCredDef!;
        this.shortCredentialUrl = shortCredentialUrl;
        this.credentialUrl = credentialUrl;
        this.credentialRecord = credentialRecord;
        this.loading = false;
      });
    } catch (e: any) {
      console.error(e);
      toast.error(e.message);
      runInAction(() => this.loading = false);
    }
  }
}

export type { RegisterPageStore };

export default RegisterPageStore;
