import React, {useEffect, useState} from "react";
import { observer } from "mobx-react";
import {Button, Spin} from 'antd';
import SchemaListPageStore from './SchemaListPageStore';
import SchemaItem from "@dashboard/components/SchemaItem";
import modalStore from "@dashboard/store/modalStore";
import NoRecordsMessage from "@dashboard/components/NoRecordsMessage";
import s from './styles.module.scss';
import PageWithSidebar from "@dashboard/components/PageWithSidebar";
import PageTitle from "@dashboard/components/PageTitle";

const ConnectionListPage = observer(() => {
  const [store] = useState(() => new SchemaListPageStore());

  useEffect(() => {
    store.loadAll()
  }, [])
  return (
    <PageWithSidebar>
      <h2>
        Actions
      </h2>
      <div>
        <Button onClick={() => {
          modalStore.openNewSchemaDialog({
            onSchemaCreated: () => {
              store.loadAll();
            }
          });
        }}>
          Create new schema
        </Button>
      </div>
      <PageTitle>Schemas</PageTitle>
      <div>
        {store.list.map(p => (
          <SchemaItem
            key={p.id}
            item={p}
          />
        ))}
        {!store.loading && store.list.length === 0 && (
          <NoRecordsMessage />
        )}
        {store.loading && (
          <Spin />
        )}
      </div>
    </PageWithSidebar>
  );
});

export default ConnectionListPage;
