import {makeAutoObservable, runInAction} from "mobx";
import api from "@dashboard/api";
import {
  CreddefRecordDto,
  ProofRecordDto,
  SchemaRecordDto
} from "@dashboard/api/agent-client";
import {toast} from "react-toastify";
import {v4} from "uuid";


class VcmSelfIssuePageStore {
  public loading = false;
  public schemas: SchemaRecordDto[] = [];
  public selectedSchemaId: string | null = null;
  public schemaUrl = "";

  constructor() {
    makeAutoObservable(this);
  }

  public async initialize() {
    runInAction(() => this.loading = true);
    try {
      const schemas = await api.listSchema();

      runInAction(() => {
        this.schemas = schemas;
        this.loading = false;
      });
    } catch (e: any) {
      console.error(e);
      toast.error(e.message);
      runInAction(() => this.loading = false);
    }
  }
}

export type { VcmSelfIssuePageStore };

export default VcmSelfIssuePageStore;
