import React, { useEffect, useState } from "react";
import { observer } from "mobx-react";
import VcmSelfIssuePageStore from "./VcmSelfIssuePageStore";
import {QRCode, Select, Spin} from "antd";
import {runInAction} from "mobx";
import PageWithSidebar from "@dashboard/components/PageWithSidebar";
import PageTitle from "@dashboard/components/PageTitle";

const VcmSelfIssuePage = observer(() => {
  const [store] = useState(() => new VcmSelfIssuePageStore());
  useEffect(() => {
    store.initialize();
  }, []);

  let url = "";
  let json = {};
  if (store.selectedSchemaId) {
    json = {
      "@type": "https://vereign.com/issue-credential/1.0/self-issue",
      schemaId: store.selectedSchemaId,
    };
    url = btoa(JSON.stringify(json));
  }

  return (
    <PageWithSidebar>
      <PageTitle>VCM: self-issued credentials</PageTitle>
      {store.loading && (
        <div>
          <Spin />
          Loading...
        </div>
      )}
      <p>
        Scan this QR code in order to create self-issued credentials
      </p>
      <div>
        <Select
          placeholder="Select schema"
          value={store.selectedSchemaId}
          onChange={(val) => {
            runInAction(() => {
              store.selectedSchemaId = val;
            });
          }}
          options={store.schemas.map((p) => ({
            value: p.id,
            label: p.name,
          }))}
        />
      </div>
      {url && (
        <QRCode
          value={url}
          size={256}
        />
      )}
      <br/>
      <div>
        Technical information:
      </div>
      <div>
        <pre>
          {JSON.stringify(json || {}, null, 2)}
        </pre>
      </div>
    </PageWithSidebar>

  );
});

export default VcmSelfIssuePage;
