import React from "react";
import { action, makeAutoObservable } from "mobx";
import {v4 as uuidv4} from "uuid";
import Modal, {FcProps} from "@dashboard/components/Modal";
import ConfirmDialog, {ConfirmDialogProps} from "@dashboard/modals/ConfirmDialog";
import ReceiveInvitationDialog, { ReceiveInvitationDialogProps } from "@dashboard/modals/ReceiveInvitationDialog";
import NewCredentialDefDialog, { NewCredentialDefDialogProps } from "@dashboard/modals/NewCredentialDefDialog";
import NewSchemaDialog, { NewSchemaDialogProps } from "@dashboard/modals/NewSchemaDialog";
import ViewJsonDialog, { ViewJsonDialogProps } from "@dashboard/modals/ViewJsonDialog";
import IssueCredentialDialog, { IssueCredentialDialogProps } from "@dashboard/modals/IssueCredentialDialog";
import RequestProofDialog, { RequestProofDialogProps } from "@dashboard/modals/RequestProofDialog";
import ViewConnectionlessProofRequest, { ViewConnectionlessProofRequestProps } from "@dashboard/modals/ViewConnectionlessProofRequest";
import AcceptConnectionlessProofRequestDialog, { AcceptConnectionlessProofRequestDialogProps } from "@dashboard/modals/AcceptConnectionlessProofRequestDialog";

class ModalStore {
  public modals: { id: string, modal: any }[] = [];

  constructor() {
    makeAutoObservable(this);
  }


  private removeModal = action((id: string) => {
    const modalIndex = this.modals.findIndex(p => p.id === id);
    if (modalIndex >= 0) {
      this.modals.splice(modalIndex, 1);
    }
  });


  protected open<TData>(Component: React.FC<FcProps<TData>>, data: TData) {
    const id = uuidv4();
    this.modals.push({
      id: id,
      modal: (
        <Modal
          Component={Component}
          onClose={() => {
            this.removeModal(id);
          }}
          data={data}
        />
      )
    });
  }

  public openConfirmDialog = (data: ConfirmDialogProps) => this.open(ConfirmDialog, data);
  public openReceiveInvitationDialog = (data: ReceiveInvitationDialogProps) => this.open(ReceiveInvitationDialog, data);
  public openNewCredentialDefDialog = (data: NewCredentialDefDialogProps) => this.open(NewCredentialDefDialog, data);
  public openNewSchemaDialog = (data: NewSchemaDialogProps) => this.open(NewSchemaDialog, data);
  public openViewJsonDialog = (data: ViewJsonDialogProps) => this.open(ViewJsonDialog, data);
  public openIssueCredentialDialog = (data: IssueCredentialDialogProps) => this.open(IssueCredentialDialog, data);
  public openRequestProofDialog = (data: RequestProofDialogProps) => this.open(RequestProofDialog, data);
  public openViewConnectionlessProofRequest = (data: ViewConnectionlessProofRequestProps) => this.open(ViewConnectionlessProofRequest, data);
  public openAcceptConnectionlessProofRequestDialog = (data: AcceptConnectionlessProofRequestDialogProps) => this.open(AcceptConnectionlessProofRequestDialog, data);

}

export type { ModalStore };

export default new ModalStore();
