import { Module, ValidationPipe } from "@nestjs/common";

import { EventsGateway } from "./events.gateway";
import { ConfigModule } from "@nestjs/config";
import { AppController } from "./app.controller";
import {
  amConfig,
  amSchema,
  cmConfig,
  cmSchema,
  gatewayConfig,
  gatewaySchema,
  pmConfig,
  pmSchema,
} from "@ocm-engine/config";
import {
  AttestationManagerClient,
  ConnectionManagerClient,
  ProofManagerClient,
} from "@ocm-engine/clients";
import Joi from "joi";
import { ConnectionController } from "./managers/connection.controller";
import { APP_PIPE } from "@nestjs/core";
import { AttestationController } from "./managers/attestation.controller";
import { ProofController } from "./managers/proof.controller";

const validationSchema = Joi.object({
  gateway: gatewaySchema,
  cm: cmSchema,
  am: amSchema,
  pm: pmSchema,
});

@Module({
  imports: [
    ConfigModule.forRoot({
      isGlobal: true,
      load: [gatewayConfig, cmConfig, amConfig, pmConfig],
      validationSchema,
    }),
  ],
  controllers: [
    AppController,
    ConnectionController,
    AttestationController,
    ProofController,
  ],
  providers: [
    EventsGateway,
    ConnectionManagerClient,
    AttestationManagerClient,
    ProofManagerClient,
    {
      provide: APP_PIPE,
      useValue: new ValidationPipe({
        transform: true,
      }),
    },
  ],
})
export class AppModule {}
