import {
  ExceptionFilter,
  Catch,
  ArgumentsHost,
  HttpException,
  HttpStatus,
  BadRequestException,
} from "@nestjs/common";

@Catch()
export class AllExceptionsHandler implements ExceptionFilter {
  catch(exception: unknown, host: ArgumentsHost) {
    const ctx = host.switchToHttp();
    const response = ctx.getResponse();

    const status =
      exception instanceof HttpException
        ? exception.getStatus()
        : HttpStatus.INTERNAL_SERVER_ERROR;

    let message: string | string[] = "Internal server error";

    if (exception instanceof Error) {
      message = exception.message;
    }

    if (exception instanceof BadRequestException) {
      message = exception.getResponse() as string[];

      response.status(status).json(message);
      return;
    }

    response.status(status).json({
      statusCode: status,
      message,
    });
  }
}
