#!/bin/bash

# Path to the Helm chart
CHART_PATH="."

# Get a list of all values-*.yaml files in the custom-values directory
VALUES_FILES=$(ls custom-values/values*.yaml)

# Max number of parallel jobs
MAX_JOBS=10
CURRENT_JOBS=0

# Loop over each values file
for VALUES_FILE in $VALUES_FILES
do
  # Extract the base name without the 'values-' prefix and '.yaml' extension
  BASE_NAME=$(basename "$VALUES_FILE" .yaml)
  BASE_NAME="${BASE_NAME#values-}"

  # Use the base name as the release name
  RELEASE_NAME="release-$BASE_NAME"

  # Run helm upgrade --install with the found values file in the background
  echo "Starting deployment for $RELEASE_NAME with $VALUES_FILE"
  helm upgrade --install "$RELEASE_NAME" "$CHART_PATH" -f "./$VALUES_FILE" -n "vereign" &

  # Increment the current jobs counter
  ((CURRENT_JOBS++))

  # If the max number of jobs is reached, wait for all jobs to complete before continuing
  if (( CURRENT_JOBS >= MAX_JOBS )); then
    wait
    CURRENT_JOBS=0
  fi
done

# Wait for the last batch of jobs to finish
wait

echo "Helm deployment completed for all values files."
