import {
  Module,
  ValidationPipe,
  MiddlewareConsumer,
  RequestMethod,
} from "@nestjs/common";
import { AgentService } from "../askar/agent.service";
import { ConfigModule, ConfigService } from "@nestjs/config";
import { LedgersModule } from "@ocm-engine/ledgers";
import { APP_PIPE } from "@nestjs/core";
import { RestController } from "./rest.controller";
import { PassportModule } from "@nestjs/passport";
import { BasicAuthMiddleware } from "./auth/basic.middleware";
import { IConfAgent } from "@ocm-engine/config";

@Module({
  imports: [ConfigModule, LedgersModule, PassportModule],
  providers: [
    AgentService,
    {
      provide: APP_PIPE,
      useValue: new ValidationPipe({
        transform: true,
      }),
    },
  ],
  controllers: [RestController],
})
export class AskarRestModule {
  constructor(private readonly configService: ConfigService) {}

  configure(consumer: MiddlewareConsumer) {
    const config: IConfAgent | undefined =
      this.configService.get<IConfAgent>("agent");

    if (config?.agentIsSVDX) {
      consumer
        .apply(BasicAuthMiddleware)
        .forRoutes({ path: "*messages", method: RequestMethod.ALL });
    }
  }
}
