import {
  Injectable,
  Logger,
  NestMiddleware,
  UnauthorizedException,
} from "@nestjs/common";
import { Request, Response, NextFunction } from "express";
import { ConfigService } from "@nestjs/config";
import { IConfAgent } from "@ocm-engine/config";

@Injectable()
export class BasicAuthMiddleware implements NestMiddleware {
  private readonly logger: Logger = new Logger(BasicAuthMiddleware.name);

  constructor(private readonly configService: ConfigService) {}

  use(req: Request, res: Response, next: NextFunction) {
    const config: IConfAgent | undefined =
      this.configService.get<IConfAgent>("agent");

    if (!config?.agentIsSVDX) {
      this.logger.log("Agent is REST only turning of basic auth");

      return next();
    }

    this.logger.log("Agent is SVDX turning basic auth middleware on");

    const authHeader = req.headers["authorization"];

    if (!authHeader) {
      return next(new UnauthorizedException());
    }

    const [username, password] = Buffer.from(authHeader.split(" ")[1], "base64")
      .toString()
      .split(":");

    if (
      username === config.agentSVDXBasicUser &&
      password === config.agentSVDXBasicPass
    ) {
      return next();
    }

    return next(new UnauthorizedException());
  }
}
