import {
  Body,
  Controller,
  Delete,
  Get,
  Param,
  Post,
  UseFilters,
} from "@nestjs/common";

import { AgentService } from "../askar/agent.service";
import {
  CreateCredentialDefinitionRequestDto,
  CreateInvitationResponseDto,
  IssueCredentialRequestDto,
  IssueProofRequestDto,
  CreateSchemaRequestDto,
  MakeBasicMessageRequestDto,
  ProofReqDto,
  IdReqDto,
  CredentialFilterDto,
  MessageFilterDto,
  ProofFilterDto,
} from "@ocm-engine/dtos";
import { AllExceptionsHandler } from "./exception.handler";

@UseFilters(AllExceptionsHandler)
@Controller("v1")
export class RestController {
  constructor(private readonly agentService: AgentService) {}

  @Post("/invitations")
  createInvitation() {
    return this.agentService.createInvitation();
  }

  @Post("/invitations/accept")
  acceptInvitation(@Body() createInvitationDto: CreateInvitationResponseDto) {
    return this.agentService.acceptInvitation(
      createInvitationDto.invitationUrl,
    );
  }

  @Get("/connections")
  connections() {
    return this.agentService.fetchConnections();
  }

  @Get("/connections/:id")
  getConnectionById(@Param("id") id: string) {
    return this.agentService.getConnectionById(id);
  }

  @Delete("/connections/:id")
  deleteConnectionById(@Param("id") id: string) {
    return this.agentService.deleteConnectionById(id);
  }

  @Post("/schemas")
  createSchema(@Body() schemaDto: CreateSchemaRequestDto) {
    return this.agentService.createSchema(schemaDto);
  }

  @Post("/schemas-by-id")
  getSchemaById(@Body() dto: IdReqDto) {
    return this.agentService.getSchemaById(dto.id);
  }

  @Get("/schemas")
  listSchema() {
    return this.agentService.fetchSchemas();
  }

  @Get("/credentials/definitions")
  credentialDefinitions() {
    return this.agentService.credentialDefinitions();
  }

  @Post("/credentials/definition-by-id")
  getCredentialDefinitionsById(@Body() credDefRequestDto: IdReqDto) {
    return this.agentService.getCredentialDefinitionsById(credDefRequestDto.id);
  }

  @Post("/credentials/definition")
  createCredentialDefinition(
    @Body() credentialDefinitionDto: CreateCredentialDefinitionRequestDto,
  ) {
    return this.agentService.createCredentialDefinition(
      credentialDefinitionDto,
    );
  }

  @Post("/credentials/issue")
  issueCredential(@Body() issueCredentialDto: IssueCredentialRequestDto) {
    return this.agentService.issueCredential(issueCredentialDto);
  }

  @Get("/credentials")
  credentials() {
    return this.agentService.credentials();
  }

  @Post("/credentials/query")
  async credentialsQuery(@Body() credentialFilterDto: CredentialFilterDto) {
    return this.agentService.queryCredentials(credentialFilterDto);
  }

  @Get("/credentials/:id")
  async getCredentialById(@Param("id") credentialId: string) {
    return this.agentService.getCredentialById(credentialId);
  }

  @Get("/credential/offers")
  getCredentialOffers() {
    return this.agentService.credentialByStatedOfferReceived();
  }

  @Post("/credentials/offers/:credential_record_id/accept")
  acceptCredential(@Param("credential_record_id") credentialRecordId: string) {
    return this.agentService.acceptCredential(credentialRecordId);
  }

  @Post("/credentials/offers/:credential_record_id/decline")
  async declineCredential(@Param("credential_record_id") credentialRecordId: string) {
    return this.agentService.declineCredential(credentialRecordId);
  }

  @Delete("/credentials/:id")
  async deleteCredentialById(@Param("id") credentialId: string) {
    return this.agentService.deleteCredentialById(credentialId);
  }

  @Post("/messages")
  sendMessage(@Body() message: MakeBasicMessageRequestDto) {
    return this.agentService.sendMessage(message);
  }

  @Post("/messages/query")
  queryMessages(@Body() filter: MessageFilterDto) {
    return this.agentService.queryBasicMessages(filter);
  }

  @Delete("/messages/:id")
  deleteMessage(@Param("id") messageId: string) {
    return this.agentService.deleteMessageById(messageId);
  }

  @Get("/credentials/proof")
  proofs() {
    return this.agentService.proofs();
  }

  @Post("/credentials/proof/query")
  proofsQuery(@Body() proofFilterDto: ProofFilterDto) {
    return this.agentService.queryProofs(proofFilterDto);
  }

  @Get("/credentials/proof/:proof_record_id")
  getProofById(@Param("proof_record_id") proofRecordId: string) {
    return this.agentService.getProofById(proofRecordId);
  }

  @Post("/credentials/proof/issue")
  issueProof(@Body() issueProofDto: IssueProofRequestDto) {
    return this.agentService.issueProof(issueProofDto);
  }

  @Post(`/credentials/proof/accept`)
  acceptProof(@Body() acceptProofRequestDto: ProofReqDto) {
    return this.agentService.acceptProof(acceptProofRequestDto);
  }

  @Post("/credentials/proof/:proof_record_id/decline")
  declineProofRequest(@Param("proof_record_id") proofRecordId: string) {
    return this.agentService.declineProofRequest(proofRecordId);
  }

  @Delete("/credentials/proof/:proof_record_id")
  async deleteProofById(@Param("proof_record_id") proofRecordId: string) {
    return this.agentService.deleteProofById(proofRecordId);
  }

  @Post("/resolve")
  resolve(@Body("did") did: string) {
    return this.agentService.resolve(did);
  }
}
