import {
  BadRequestException,
  Injectable,
  InternalServerErrorException,
  Logger,
} from "@nestjs/common";
import {
  ClientProxy,
  ClientProxyFactory,
  Transport,
} from "@nestjs/microservices";
import { ConfigService } from "@nestjs/config";
import {
  IAttestationManagerConfig,
  IConnectionManagerConfig,
} from "@ocm-engine/config";
import { lastValueFrom } from "rxjs";

@Injectable()
export class AttestationManagerClient {
  private client: ClientProxy;
  private cmConfig: IAttestationManagerConfig;
  private readonly logger: Logger = new Logger(AttestationManagerClient.name);

  constructor(configService: ConfigService) {
    this.cmConfig = configService.get<IConnectionManagerConfig>("am")!;

    this.client = ClientProxyFactory.create({
      transport: Transport.TCP,
      options: {
        host: this.cmConfig.host,
        port: this.cmConfig.port,
      },
    });
  }

  async sendPayload<T>({
    pattern,
    payload,
  }: {
    pattern: string;
    payload: {
      data: T;
      type: string;
      source: string;
    };
  }): Promise<{
    id: string;
  }> {
    this.logger.debug(
      `sending payload to attestation manager ${JSON.stringify(
        payload,
        null,
        2,
      )}`,
    );

    return lastValueFrom(this.client.send(pattern, payload)).catch((e) => {
      throw new InternalServerErrorException(e.message);
    });
  }
}
