import {
  BadRequestException,
  Injectable,
  InternalServerErrorException,
  Logger,
} from "@nestjs/common";
import {
  ClientProxy,
  ClientProxyFactory,
  Transport,
} from "@nestjs/microservices";
import { ConfigService } from "@nestjs/config";
import {
  IConnectionManagerConfig,
  IProofManagerConfig,
} from "@ocm-engine/config";
import { lastValueFrom } from "rxjs";

@Injectable()
export class ProofManagerClient {
  private client: ClientProxy;
  private pmConfig: IProofManagerConfig;
  private readonly logger: Logger = new Logger(ProofManagerClient.name);

  constructor(configService: ConfigService) {
    this.pmConfig = configService.get<IProofManagerConfig>("pm")!;

    this.client = ClientProxyFactory.create({
      transport: Transport.TCP,
      options: {
        host: this.pmConfig.host,
        port: this.pmConfig.port,
      },
    });
  }

  async sendPayload<T>({
    pattern,
    payload,
  }: {
    pattern: string;
    payload: {
      data: T;
      type: string;
      source: string;
    };
  }): Promise<{
    id: string;
  }> {
    this.logger.debug(
      `sending payload to proof manager ${JSON.stringify(payload, null, 2)}`,
    );

    return lastValueFrom(this.client.send(pattern, payload)).catch((e) => {
      throw new InternalServerErrorException(e.message);
    });
  }
}
