export type ConnectionEvent =
  | "connections.create"
  | "connections.accept"
  | "connections.list"
  | "connections.get"
  | "connections.delete";

export const CONNECTION_CREATE: ConnectionEvent = "connections.create";
export const CONNECTION_ACCEPT: ConnectionEvent = "connections.accept";
export const CONNECTION_LIST: ConnectionEvent = "connections.list";
export const CONNECTION_GET: ConnectionEvent = "connections.get";
export const CONNECTION_DELETE: ConnectionEvent = "connections.delete";

export const CONNECTION_EVENTS: ConnectionEvent[] = [
  CONNECTION_CREATE,
  CONNECTION_ACCEPT,
  CONNECTION_LIST,
  CONNECTION_GET,
  CONNECTION_DELETE,
];

export type SchemaEvent = "schemas.create" | "schemas.get" | "schemas.list";
export const SCHEMA_CREATE: SchemaEvent = "schemas.create";
export const SCHEMA_GET: SchemaEvent = "schemas.get";
export const SCHEMA_LIST: SchemaEvent = "schemas.list";

export const SCHEMA_EVENTS: SchemaEvent[] = [
  SCHEMA_CREATE,
  SCHEMA_LIST,
  SCHEMA_GET,
];

export type CredentialEvent =
  | "credentials.definition.create"
  | "credentials.issue"
  | "credentials.list"
  | "credentials.offer.list"
  | "credentials.offer.accept"
  | "credentials.offer.decline"
  | "credentials.definition.list"
  | "credentials.definition.get"
  | "credentials.offer.query"
  | "credentials.offer.delete"
  | "credentials.offer.get";

export const CRED_DEF_CREATE: CredentialEvent = "credentials.definition.create";
export const CRED_DEF_LIST: CredentialEvent = "credentials.definition.list";
export const CRED_DEF_GET: CredentialEvent = "credentials.definition.get";

export const CRED_ISSUE: CredentialEvent = "credentials.issue";
export const CRED_LIST: CredentialEvent = "credentials.list";
export const CRED_OFFER_LIST: CredentialEvent = "credentials.offer.list";
export const CRED_OFFER_ACCEPT: CredentialEvent = "credentials.offer.accept";
export const CRED_OFFER_DECLINE: CredentialEvent = "credentials.offer.decline";
export const CRED_QUERY: CredentialEvent = "credentials.offer.query";
export const CRED_DELETE: CredentialEvent = "credentials.offer.delete";
export const CRED_GET: CredentialEvent = "credentials.offer.get";

export const CRED_EVENTS: CredentialEvent[] = [
  CRED_DEF_CREATE,
  CRED_DEF_LIST,
  CRED_DEF_GET,
  CRED_ISSUE,
  CRED_LIST,
  CRED_OFFER_LIST,
  CRED_OFFER_ACCEPT,
  CRED_OFFER_DECLINE,
  CRED_QUERY,
  CRED_DELETE,
  CRED_GET,
];

export type ProofEvent =
  | "proofs.list"
  | "proofs.accept"
  | "proofs.issue"
  | "proofs.get"
  | "proofs.decline"
  | "proofs.query"
  | "proofs.delete";

export const PROOF_LIST: ProofEvent = "proofs.list";
export const PROOF_QUERY: ProofEvent = "proofs.query";
export const PROOF_DELETE: ProofEvent = "proofs.delete";
export const PROOF_GET: ProofEvent = "proofs.get";
export const PROOF_ACCEPT: ProofEvent = "proofs.accept";
export const PROOF_ISSUE: ProofEvent = "proofs.issue";
export const PROOF_DECLINE: ProofEvent = "proofs.decline";

export const PROOF_EVENTS: ProofEvent[] = [
  PROOF_ACCEPT,
  PROOF_LIST,
  PROOF_ISSUE,
  PROOF_GET,
  PROOF_DECLINE,
  PROOF_QUERY,
  PROOF_DELETE,
];

export type BasicMessageEvent =
  | "messages.make"
  | "messages.query"
  | "messages.delete";

export const MESSAGES_MAKE = "messages.make";
export const MESSAGES_QUERY = "messages.query";
export const MESSAGES_DELETE = "messages.delete";

export const DIDCOMM_EVENTS: BasicMessageEvent[] = [
  MESSAGES_MAKE,
  MESSAGES_QUERY,
  MESSAGES_DELETE,
];

export const ALL_EVENTS = [
  ...SCHEMA_EVENTS,
  ...CRED_EVENTS,
  ...PROOF_EVENTS,
  ...CONNECTION_EVENTS,
  ...DIDCOMM_EVENTS,
];
