import { Injectable, Logger } from "@nestjs/common";
import { IRegistrator } from "../IRegistrator";
import genesisFile from "./genesis-file";
import axios, { AxiosError } from "axios";
import { IndyVdrPoolConfig } from "@aries-framework/indy-vdr";
import { LedgerProviderFailRegistrationError } from "@ocm-engine/dtos";

const NAME = "DIDGRAM_TEST";
const URL = "http://ledger.didgram.pro/register";

@Injectable()
export class DidgramTestProvider implements IRegistrator {
  private readonly logger: Logger = new Logger(DidgramTestProvider.name);

  getName = (): string => {
    return NAME;
  };

  register = async (
    unqualifiedIndyDid: string,
    verkey: string,
  ): Promise<string> => {
    const did = `did:indy:didgram:test:${unqualifiedIndyDid}`;

    this.logger.log(`Trying to register ${did} to didram test`);
    try {
      await axios.post(URL, {
        did: unqualifiedIndyDid,
        verkey,
        role: "ENDORSER",
      });

      this.logger.log("Registration successful");
      return did;
    } catch (e) {
      this.logger.log("Registration failed");
      this.logger.log("DIDGRAM Registration failed");

      if (e instanceof Error || e instanceof AxiosError) {
        throw new LedgerProviderFailRegistrationError(e.message);
      }
      throw new Error("DIDGRAM registration fail - Reason UNKNOWN");
    }
  };

  getNetworkConf = (): IndyVdrPoolConfig => {
    return {
      genesisTransactions: genesisFile,
      indyNamespace: "didgram:test",
      isProduction: false,
      connectOnStartup: true,
    };
  };
}
