﻿using NJsonSchema.CodeGeneration.CSharp;
using NSwag;
using NSwag.CodeGeneration.CSharp;

if (args.Length != 4)
  throw new ArgumentException("Expecting 2 arguments: URL, generatePath");

var path = args[0];
var generatePath = Path.Combine(Directory.GetCurrentDirectory(), args[1]);
var classNamespace = args[2];
var className = args[3];

async static Task GenerateTypeScriptClient(string path, string generatePath, string classNamespace, string className) =>
  await GenerateClient(
    document: await OpenApiDocument.FromFileAsync(path),
    generatePath: generatePath,
    generateCode: (OpenApiDocument document) => {
      var settings = new CSharpClientGeneratorSettings {
        ClassName = className,
        CSharpGeneratorSettings = {
          Namespace = classNamespace
        }
      };
      // settings.CSharpGeneratorSettings.NullValue = TypeScriptNullValue.Null;
      // settings.CSharpGeneratorSettings.TypeStyle = TypeScriptTypeStyle.Interface;
      // settings.CSharpGeneratorSettings.TypeScriptVersion = 5.1M;
      // settings.CSharpGeneratorSettings.DateTimeType = TypeScriptDateTimeType.Date;

      var generator = new CSharpClientGenerator(document, settings);
      var code = generator.GenerateFile();

      // code = code.Replace("protected jsonParseReviver", "public jsonParseReviver");
      return code;
    }
  );

await GenerateTypeScriptClient(path, generatePath, classNamespace, className);

async static Task GenerateClient(OpenApiDocument document, string generatePath, Func<OpenApiDocument, string> generateCode)
{
  Console.WriteLine($"Generating {generatePath}...");

  var code = generateCode(document);

  await System.IO.File.WriteAllTextAsync(generatePath, code);
}
